Welcome to Ape's documentation!
===============================

.. toctree::
   :caption: Table of Contents
   :name: mastertoc
   :maxdepth: 2

   quickstart

.. toctree::
   :caption: User API Reference
   :name: userapiref
   :maxdepth: 1
   :hidden:

   autoapi/ape/index.rst
   autoapi/ape/api/index.rst
   autoapi/ape/types/index.rst
   autoapi/ape/utils/index.rst

User-facing API Reference
-------------------------

Import these modules when using the Ape console or writing scripts for the Ape framework.

* :doc:`ape <autoapi/ape/index>`: Top-level API used for most common tasks
* :doc:`ape.api <autoapi/ape/api/index>`: API building blocks for blockchain development
* :doc:`ape.types <autoapi/ape/types/index>`: Common data types for interacting with the blockchain
* :doc:`ape.utils <autoapi/ape/utils/index>`: Utility functions

.. toctree::
   :caption: Full API Reference
   :name: fullapiref
   :hidden:

   autoapi/index.rst

Full API Reference
------------------

See the :doc:`autoapi module index <autoapi/index>` for the full ``ape`` API reference.

Indices
=======

* :ref:`genindex`
* :ref:`modindex`
